NAME = "bluer_journal"

ICON = "📜"

DESCRIPTION = f"{ICON} A journal for the age of AI."

VERSION = "5.81.1"

REPO_NAME = "bluer-journal"

MARQUEE = "https://github.com/kamangir/assets/raw/main/blue-plugin/marquee.png?raw=true"

ALIAS = "@journal"


def fullname() -> str:
    return f"{NAME}-{VERSION}"
